@@ -2,8 +2,8 @@ import gzip
 import pickle
 from io import DEFAULT_BUFFER_SIZE
 from json import dump, load
-from os import makedirs
-from os.path import exists, dirname, join, basename
+from os import makedirs, remove, rmdir, PathLike
+from os.path import exists, dirname, join, basename, isdir
 from shutil import copyfile
 from typing import Union, Optional, TextIO, Any
 
@@ -101,7 +101,7 @@ def force_open(filename: Union[str, bytes, int],
     return open_file(filename, mode, buffering, encoding, errors, newline, close_fd, opener=opener)
 
 
-def copy_files(dest: str, *files, force: bool = True) -> None:
+def copy_files(dest: str, *files: str, force: bool = True) -> None:
     """ Copy a list of files into destination folder.
     :param dest: The destination folder.
     :param files: The list of files to copy.
@@ -149,3 +149,87 @@ def load_pickle(filename: str) -> Any:
     """
     with open_file(filename, 'rb') as file:
         return pickle.load(file)
+
+
+def gzip_decompress(input_file: str, output_file: str) -> None:
+    """ Decompress a file using gzip compression.
+    :param input_file: The file to compress.
+    :param output_file: The compressed file with all the information of the input file.
+    """
+    if input_file == output_file:
+        raise ValueError('The input file and the output file must be different.')
+    with open(output_file, 'wb') as writer:
+        with gzip.open(input_file, 'rb') as reader:
+            for chunk in reader:
+                writer.write(chunk)
+
+
+def gzip_compress(input_file: str, output_file: str) -> None:
+    """ Compress a file using gzip compression.
+    :param input_file: The file to compress.
+    :param output_file: The compressed file with all the information of the input file.
+    """
+    if input_file == output_file:
+        raise ValueError('The input file and the output file must be different.')
+    with gzip.open(output_file, 'wb') as writer:
+        with open(input_file, 'rb') as reader:
+            for chunk in reader:
+                writer.write(chunk)
+
+
+def remove_files(*files: str, ignore_errors: bool = False) -> None:
+    """ Remove several files and empty directories at once.
+
+    :param files: The list of files or empty directories to remove. To remove directories with files or subdirectories,
+      please, use shutil.rmtree().
+    :param ignore_errors: If True, ignore the error if the file or directory does not exist.
+    """
+    for file in files:
+        if isdir(file):
+            rmdir(file)
+        elif not ignore_errors or exists(file):
+            remove(file)
+
+
+def first_line(filename: str) -> str:
+    """ Read the first line of a file removing the final \n if it exists.
+
+    :param filename: The filename to read.
+    :return: A string with the first line.
+    """
+    with open_file(filename) as file:
+        line = file.readline()
+        return line[:-1] if line.endswith('\n') else line
+
+
+def exist_files(*files: Union[str, bytes]) -> bool:
+    """ Check if a sequence of files exist.
+
+    :param files: The list of file paths to check.
+    :return: True if all the files exist, otherwise False.
+    """
+    for file in files:
+        if not exists(file):
+            return False
+    return True
+
+
+def count_lines(filename: str) -> int:
+    """ Calculate the number of lines in a file.
+
+    :param filename: The filename to calculate its size.
+    :return: The number of lines of the file.
+    """
+    count = 0
+    with open_file(filename) as file:
+        for _ in file:
+            count += 1
+    return count
+
+
+def touch(filename: str) -> None:
+    """ Create an empty file.
+
+    :param filename: The path to the file to create.
+    """
+    open(filename, 'w').close()
